@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiClassEdit.cpp,v 1.10 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiClassEdit.cpp,v 1.13 2011/01/09 01:59:31 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -491,11 +491,17 @@ void GuiClassEdit::wipe()
 void	GuiClassEdit::setClassName()
 {
 #ifdef D_GTK
-	const gchar *name = gtk_entry_get_text(
-			GTK_ENTRY( mEntryName ) );
-
+	const gchar *name = cut_utf_str( gtk_entry_get_text( GTK_ENTRY( mEntryName ) ),
+			CLASS_NAME_MAX_LEN );
 	str_nz_cpy( classData->name, name, CLASS_NAME_MAX_BYTE );
 #endif // D_GTK
+
+#ifdef D_MFC
+	mClassEditWin->UpdateData( TRUE );
+	const char *sName = cut_utf_str( mClassEditWin->mEditName,
+			MBR_NAME_MAX_LEN );
+	str_nz_cpy( classData->name, sName, CLASS_NAME_MAX_BYTE );
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -526,6 +532,8 @@ void GuiClassEdit::minusClicked( abl_kind_t kind )
 
 void GuiClassEdit::add( abl_kind_t kind, long n )
 {
+	setClassName();
+
 	edit_class_t ec;
 	if( kind < ABL_KIND_FIG )
 		ec = (edit_class_t)(EDIT_CLASS_HP + (kind - ABL_KIND_HP));
