@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.31 2010/07/18 07:12:42 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.33 2011/01/09 01:59:31 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -1069,7 +1069,7 @@ gint handle_num_ok_clicked(
 )
 {
 	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
-		gGuiNum.okClicked( (menu_num_t)(int)data );
+		gGuiNum.okClicked( (menu_num_t)(long)data );
 	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
 		gKey.setChar( '0' );
 	}
